@@ -262,9 +262,9 @@ def build_set_data(relic_list, pd_file=None):
         parts = {'parts': {}}
 
         for j, _p in enumerate(_ps[1:]):
-            parts['parts'][_p] = {'plat': price_info(fix_name(_p), price_data),
-                                  'ducats': ducat_info(fix_name(_p), wfcd_api),
-                                  'required': required_info(fix_name(_p), wfcd_api)}
+            parts['parts'][_p] = {'plat': price_info(_p, price_data),
+                                  'ducats': ducat_info(_p, wfcd_api),
+                                  'required': required_info(_p, wfcd_api)}
 
         set_data[_ps[0]] = parts
         set_data[_ps[0]]['vaulted'] = vaulted_info(_ps[0], wfcd_api)
